Align Urdf Mjcf
i2rt-robotics/i2rt
Align a MuJoCo MJCF robot model with a URDF source while preserving kinematics, geometry, masses, centers of mass, and inertia tensors.
Add standard or advanced autotuning to Triton-Ascend kernels, define shape keys and candidate meta-parameters, and structure kernels so automatic split and tiling analysis can recognize their axes.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a claude-codeProject install by default; add -g for ~/.claude/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tune-triton-ascend-kernels --agent claude-codeProject scope by default; add --scope user for a personal install. Needs GitHub CLI 2.90.0 or later (public preview).
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .claude/skills && cp -r skills-src/skills/tune-triton-ascend-kernels .claude/skills/tune-triton-ascend-kernels && rm -rf skills-srcUse ~/.claude/skills/ instead of .claude/skills for a personal install. The folder must contain SKILL.md.
Claude Code skills documentation · loads skills from .claude/skills/
Install the "tune-triton-ascend-kernels" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernels into .claude/skills/tune-triton-ascend-kernels/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tune-triton-ascend-kernels", then confirm the skill loads.Claude Code copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$skill-installer install https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernelsType this inside Codex. $skill-installer <name> installs a curated skill from openai/skills. The installer writes to $CODEX_HOME/skills (default ~/.codex/skills). Restart Codex if the skill does not show up.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a codexProject install goes to .agents/skills/; add -g for ~/.codex/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tune-triton-ascend-kernels --agent codexProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .agents/skills && cp -r skills-src/skills/tune-triton-ascend-kernels .agents/skills/tune-triton-ascend-kernels && rm -rf skills-srcUse ~/.agents/skills/ instead of .agents/skills for a personal install.
Codex skills documentation · loads skills from .agents/skills/
Install the "tune-triton-ascend-kernels" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernels into .agents/skills/tune-triton-ascend-kernels/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tune-triton-ascend-kernels", then confirm the skill loads.Codex copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a cursorProject install goes to .agents/skills/; add -g for ~/.cursor/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tune-triton-ascend-kernels --agent cursorProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .cursor/skills && cp -r skills-src/skills/tune-triton-ascend-kernels .cursor/skills/tune-triton-ascend-kernels && rm -rf skills-srcUse ~/.cursor/skills/ instead of .cursor/skills for a personal install.
Cursor skills documentation · loads skills from .cursor/skills/, .agents/skills/, .claude/skills/, .codex/skills/
Install the "tune-triton-ascend-kernels" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernels into .cursor/skills/tune-triton-ascend-kernels/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tune-triton-ascend-kernels", then confirm the skill loads.Cursor copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gemini skills install https://github.com/Krusty84/triton-ascend-agent-dev-kit.git --path skills/tune-triton-ascend-kernels--scope user (default) or --scope workspace; --path is the subfolder of the repo that holds the skill; --consent skips the security confirmation prompt.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a gemini-cliProject install goes to .agents/skills/; add -g for ~/.gemini/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tune-triton-ascend-kernels --agent gemini-cliProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .gemini/skills && cp -r skills-src/skills/tune-triton-ascend-kernels .gemini/skills/tune-triton-ascend-kernels && rm -rf skills-srcUse ~/.gemini/skills/ instead of .gemini/skills for a personal install, then run /skills reload.
Gemini CLI skills documentation · loads skills from .gemini/skills/, .agents/skills/
Install the "tune-triton-ascend-kernels" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernels into .gemini/skills/tune-triton-ascend-kernels/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tune-triton-ascend-kernels", then confirm the skill loads.Gemini CLI copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tune-triton-ascend-kernelsInstalls for Copilot at project scope by default; add --scope user for a personal install. Preview a skill first with gh skill preview. Needs GitHub CLI 2.90.0 or later (public preview).
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a github-copilotProject install goes to .agents/skills/; add -g for ~/.copilot/skills/.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .github/skills && cp -r skills-src/skills/tune-triton-ascend-kernels .github/skills/tune-triton-ascend-kernels && rm -rf skills-srcUse ~/.copilot/skills/ instead of .github/skills for a personal install. Commit .github/skills so cloud agent and code review can use it.
GitHub Copilot skills documentation · loads skills from .github/skills/, .claude/skills/, .agents/skills/
Install the "tune-triton-ascend-kernels" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernels into .github/skills/tune-triton-ascend-kernels/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tune-triton-ascend-kernels", then confirm the skill loads.GitHub Copilot copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
$ npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a opencodeOpenCode documents no install command of its own. Project install goes to .agents/skills/; add -g for ~/.config/opencode/skills/.
$ gh skill install Krusty84/triton-ascend-agent-dev-kit tune-triton-ascend-kernels --agent opencodeProject scope by default (.agents/skills/); add --scope user for a personal install.
$ git clone --depth 1 https://github.com/Krusty84/triton-ascend-agent-dev-kit.git skills-src && mkdir -p .opencode/skills && cp -r skills-src/skills/tune-triton-ascend-kernels .opencode/skills/tune-triton-ascend-kernels && rm -rf skills-srcUse ~/.config/opencode/skills/ instead of .opencode/skills for a personal install.
OpenCode skills documentation · loads skills from .opencode/skills/, .claude/skills/, .agents/skills/
Install the "tune-triton-ascend-kernels" agent skill from https://github.com/Krusty84/triton-ascend-agent-dev-kit/tree/main/skills/tune-triton-ascend-kernels into .opencode/skills/tune-triton-ascend-kernels/ in this project. Copy the whole folder (SKILL.md and every file beside it), keep the folder name "tune-triton-ascend-kernels", then confirm the skill loads.OpenCode copies the folder itself, the same result as the manual copy. Check what it changed before you commit it.
tune-triton-ascend-kernelsAdd standard or advanced autotuning to Triton-Ascend kernels, define shape keys and candidate meta-parameters, and structure kernels so automatic split and tiling analysis can recognize their axes.
Tune Triton Ascend Kernels is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Add standard or advanced autotuning to Triton-Ascend kernels, define shape keys and candidate meta-parameters, and structure kernels so automatic split and tiling analysis can recognize their axes. Use when an agent needs to benchmark block-size or multibuffer choices, use configs=[] for generated vector-kernel candidates, or diagnose why Triton-Ascend autotune cannot infer a tunable axis.
Its SKILL.md is about 810 tokens, which your agent loads only when the skill is triggered. It is a single SKILL.md file with no bundled scripts.
It sits in AI & LLM Engineering, covering Accessibility. The repository describes itself as: A toolkit for AI agents used for development on Triton-Ascend for Ascend NPU. The licence is Apache-2.0.
6 steps, taken from the first numbered list in SKILL.md.
Read from SKILL.md and the folder at commit 4ab5ee7. It shows what the files ask for, not the result of running them.
Pre-approves nothing: there is no allowed-tools line, so your agent's usual permission prompts apply.
From allowed-tools in the SKILL.md frontmatter.
No scripts in the folder and no shell commands in SKILL.md (its code samples are python).
From the folder's file list and the shell code blocks in SKILL.md.
No URLs in SKILL.md.
From URLs in SKILL.md, links to its own repository left out.
Names no API keys, tokens, secrets or passwords.
From names ending in _API_KEY, _TOKEN, _SECRET, _KEY or _PASSWORD in SKILL.md.
Tune Triton Ascend Kernels loads about 813 tokens when it runs. Until then it costs about 105 tokens; SKILL.md has 257 words of instructions outside code blocks.
Estimates: characters ÷ 4, the usual rule of thumb; real counts depend on the model's tokenizer. Scripts and assets cost tokens only if the agent reads them.
The automated check found no risky patterns in SKILL.md.
Automated static check — not a guarantee. Review scripts before installing. It scans the text of SKILL.md for risky patterns (piping downloads into a shell, reading credential files, hidden Unicode, destructive commands); files beside SKILL.md are not scanned.
The full file from Krusty84/triton-ascend-agent-dev-kit at commit 4ab5ee7, republished under its Apache-2.0 licence (© Krusty84). 257 words, ~813 tokens.
.claude/skills/tune-triton-ascend-kernels/SKILL.md (or your agent's skills folder).Select a correct kernel configuration for each relevant input shape without hardcoding one block size for all workloads.
Use explicit candidates for standard autotune:
@triton.autotune(
configs=[
triton.Config({"XS": 128, "multibuffer": True}),
triton.Config({"XS": 8192, "multibuffer": False}),
],
key=["numel"],
)
@triton.jit
def kernel(out_ptr, x_ptr, numel, XS: tl.constexpr):
offsets = tl.program_id(0) * XS + tl.arange(0, XS)
mask = offsets < numel
values = tl.load(x_ptr + offsets, mask=mask)
tl.store(out_ptr + offsets, values, mask=mask)Use generated candidates for advanced vector autotune:
@triton.autotune(
configs=[],
key={"x": "n_elements"},
split_params={"x": "BLOCK_SIZE"},
tiling_params={},
low_dims=["x"],
persistent_reduction=False,
dual_reduction=False,
)
@triton.jit
def kernel(out_ptr, x_ptr, n_elements, BLOCK_SIZE: tl.constexpr):
offsets = tl.program_id(0) * BLOCK_SIZE + tl.arange(0, BLOCK_SIZE)
mask = offsets < n_elements
values = tl.load(x_ptr + offsets, mask=mask)
tl.store(out_ptr + offsets, values, mask=mask)Compare the selected kernel with the PyTorch reference for every key shape and inspect that retuning happens when the key changes. Benchmark the winner separately; autotune success does not replace correctness tests.
© Krusty84, Apache-2.0. Rendered from Markdown: HTML in the file is shown as text, images as links, and headings moved down two levels. Raw file
Just SKILL.md in skills/tune-triton-ascend-kernels of Krusty84/triton-ascend-agent-dev-kit.
Open the folder on GitHubat commit 4ab5ee7
Tune Triton Ascend Kernels next to the 5 skills that share the most tags, products or categories with it. Stars are the repository's; “used in” counts other GitHub owners with a copy.
| Skill | Stars | Used in | Tokens | Auto-check | Licence | Repo updated |
|---|---|---|---|---|---|---|
| Tune Triton Ascend Kernels this skillKrusty84/triton-ascend-agent-dev-kit | 106 | — | ~813 | Automated safety check: Pass | Apache-2.0 | |
| Align Urdf Mjcfi2rt-robotics/i2rt | 168 | — | ~4.4k | Automated safety check: Pass | MIT | |
| Streaming Responsethedaviddias/ux-patterns-for-developers | 259 | — | ~1k | Automated safety check: Pass | Custom licence | |
| Color Pickerthedaviddias/ux-patterns-for-developers | 259 | — | ~1.3k | Automated safety check: Pass | Custom licence | |
| Date Pickerthedaviddias/ux-patterns-for-developers | 259 | — | ~1.5k | Automated safety check: Pass | Custom licence | |
| Hambuger Menuthedaviddias/ux-patterns-for-developers | 259 | — | ~1.2k | Automated safety check: Pass | Custom licence |
i2rt-robotics/i2rt
Align a MuJoCo MJCF robot model with a URDF source while preserving kinematics, geometry, masses, centers of mass, and inertia tensors.
thedaviddias/ux-patterns-for-developers
A skill your agent uses when implementing real-time AI response streaming.
thedaviddias/ux-patterns-for-developers
A skill your agent uses when implementing select colors with visual feedback.
thedaviddias/ux-patterns-for-developers
A skill your agent uses when implementing select dates from a calendar interface.
thedaviddias/ux-patterns-for-developers
A skill your agent uses when you need to display a menu icon for mobile devices.
thedaviddias/ux-patterns-for-developers
A skill your agent uses when implementing user registration and account creation.
Krusty84/triton-ascend-agent-dev-kit
Implements request-to-token-pool copies for Triton kernels on Ascend NPUs, replacing loop-carried vector offsets with fixed-offset block loops that compile reliably.
Krusty84/triton-ascend-agent-dev-kit
Writes a Triton kernel pattern for Ascend NPU that gathers several indexed token rows per program into an on-chip buffer and stores one contiguous output tile, for MoE-style token reordering.
Krusty84/triton-ascend-agent-dev-kit
Builds Triton-Ascend kernels that pack sorted token assignments into fixed expert-capacity tensors, restore top-k outputs and compute router-weight gradients on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Guides building a FlashAttention-v2-style fused forward attention kernel for Triton-Ascend on Ascend NPU, with online softmax, causal staging and float32 accumulation.
Krusty84/triton-ascend-agent-dev-kit
Builds a fused row-wise softmax kernel for Triton-Ascend that reads and writes each row once, handling padding, strides and masked loads on Ascend NPUs.
Krusty84/triton-ascend-agent-dev-kit
Build a fused forward LayerNorm kernel for Triton-Ascend with row-wise mean and variance reductions, float32 accumulation, affine weight and bias, and masked feature tiles.
Categories
Add standard or advanced autotuning to Triton-Ascend kernels, define shape keys and candidate meta-parameters, and structure kernels so automatic split and tiling analysis can recognize their axes. Tune Triton Ascend Kernels is an agent skill from Krusty84/triton-ascend-agent-dev-kit. Add standard or advanced autotuning to Triton-Ascend kernels, define shape keys and candidate meta-parameters, and structure kernels so automatic split and tiling analysis can recognize their axes.
Tune Triton Ascend Kernels fits situations like: an agent needs to benchmark block-size; multibuffer choices; use configs=[] for generated vector-kernel candidates; diagnose why Triton-Ascend autotune cannot infer a tunable axis.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a claude-code`. Or copy the skill folder (skills/tune-triton-ascend-kernels in Krusty84/triton-ascend-agent-dev-kit) into .claude/skills/tune-triton-ascend-kernels in your project. Claude Code loads it when a task matches its description.
Run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a codex`. Or copy the skill folder (skills/tune-triton-ascend-kernels in Krusty84/triton-ascend-agent-dev-kit) into .agents/skills/tune-triton-ascend-kernels in your project. Codex loads it when a task matches its description.
Cursor, Gemini CLI, GitHub Copilot and OpenCode also load SKILL.md folders. With the skills CLI, run `npx skills add Krusty84/triton-ascend-agent-dev-kit --skill tune-triton-ascend-kernels -a cursor` (or -a gemini-cli, github-copilot or opencode for the others). To copy it by hand, put the folder in .cursor/skills/tune-triton-ascend-kernels, .gemini/skills/tune-triton-ascend-kernels, .github/skills/tune-triton-ascend-kernels and .opencode/skills/tune-triton-ascend-kernels in your project.
SKILL.md names no scripts, command-line tools or credentials: Tune Triton Ascend Kernels is instructions for the agent only. Our summary lists: Python 3.
SKILL.md contains no URLs. Any network use would come from the scripts or tools the agent runs. This is read from the text; nothing was executed.
Our automated static check of SKILL.md found no risky patterns, such as piping downloads into a shell, reading credential files or hidden Unicode. It is not a guarantee. Review the folder before installing.
Tune Triton Ascend Kernels is published under the Apache-2.0 licence (the repository's licence). It allows redistribution, so the full SKILL.md is shown on this page.
About 813 tokens (SKILL.md is roughly 3.3k characters). Agents keep only the skill's name and description in context until a task matches; then they load SKILL.md in full.
Skills that share tags, products or a category with Tune Triton Ascend Kernels: Align Urdf Mjcf (i2rt-robotics/i2rt, 168 stars), Streaming Response (thedaviddias/ux-patterns-for-developers, 259 stars), Color Picker (thedaviddias/ux-patterns-for-developers, 259 stars) and Date Picker (thedaviddias/ux-patterns-for-developers, 259 stars). The comparison table on this page puts their stars, adoption, token cost, safety result and licence side by side.
Krusty84 (a GitHub user) maintains it in Krusty84/triton-ascend-agent-dev-kit, which has 106 GitHub stars. The repository holds 23 skills in this directory. The repository was last updated on August 15, 2026.
Source: Krusty84/triton-ascend-agent-dev-kit on GitHub. Facts on this page come from the repository at the commit we read; the author's words are quoted as theirs.